@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
@@ -33,15 +32,15 @@ CONF = cfg.CONF
 
 
 def main():
-    # Pase config file and command line options, then start logging
+    # Parse config file and command line options, then start logging
     tuskar_service.prepare_service(sys.argv)
 
     # Build and start the WSGI app
     host = CONF.tuskar_api_bind_ip
     port = CONF.tuskar_api_port
     wsgi = simple_server.make_server(
-            host, port,
-            app.VersionSelectorApplication())
+        host, port,
+        app.VersionSelectorApplication())
 
     LOG = log.getLogger(__name__)
     LOG.info("Serving on http://%s:%s" % (host, port))
@@ -52,10 +51,12 @@ def main():
     try:
         os.listdir(heat_template_path)
     except OSError:
-        LOG.info("Can't find local tripleo-heat-template files at %s"
-                  % (heat_template_path))
-        LOG.info("Cannot proceed - missing tripleo heat templates " +
-                  "See INSTALL documentation for more info")
+        LOG.info(
+            "Can't find local tripleo-heat-template files at %s"
+            % (heat_template_path))
+        LOG.info(
+            "Cannot proceed - missing tripleo heat templates "
+            "See INSTALL documentation for more info")
         raise
     LOG.info("Using tripleo-heat-templates at %s" % (heat_template_path))
 
